==> Mapster-1.4.3.zip: Mapster/Locale/enUS.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local debug = false
--[===[@debug@
debug = true
--@end-debug@]===]

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "enUS", true, debug)

L["(Mini) Disable Mouse"] = true
L["(Mini) Hide Border"] = true
L["Accuracy"] = true
L["Adjust the size of the Player Arrow on the Map for better visibility."] = true
L["Alpha"] = true
L["BattleMap"] = true
L["Battlegrounds"] = true
L["Blobs & Panels"] = true
L["Burning Crusade Instances"] = true
L["Burning Crusade Raids"] = true
L["Cataclysm Instances"] = true
L["Cataclysm Raids"] = true
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = true
L["Classic Instances"] = true
L["Classic Raids"] = true
L["Coordinates"] = true
L["Cursor"] = true
L["Debug"] = true
L["Disable Mouse"] = true
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = true
L["Disable the mouse interactivity of the main map, eg. to change zones."] = true
L["Enable BattleMap"] = true
L["Enable Coordinates"] = true
L["Enable FogClear"] = true
L["Enable Group Icons"] = true
L["Enable Instance Maps"] = true
L["FogClear"] = true
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = true
L["Group Icons"] = true
L["Hide Border"] = true
L["Hide Completely"] = true
L["Hide Map Button"] = true
L["Hide Textures"] = true
L["Hide the borders of the big map."] = true
L["Hide the borders of the minimized map."] = true
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = true
L["Instance Maps"] = true
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = true
L["Minimized Alpha"] = true
L["Minimized Scale"] = true
L["Note: You need to reload your UI after reseting the data!"] = true
L["Only WorldMap Blobs"] = true
L["Overlay Color"] = true
L["POI Scale"] = true
L["Player"] = true
L["PlayerArrow Scale"] = true
L["Quest Objectives"] = true
L["Reset FogClear Data"] = true
L["Scale"] = true
L["Scale of the POI Icons on the Map."] = true
L["Scale of the big map."] = true
L["Scale of the minimized map."] = true
L["Size on the Battle Map"] = true
L["Size on the World Map"] = true
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = true
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = true
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = true
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = true
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = true
L["The transparency of the big map."] = true
L["The transparency of the minimized map."] = true
L["Turn on debugging for the FogClear Module."] = true
L["Wrath Instances"] = true
L["Wrath Raids"] = true
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = true
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = true

==> Mapster-1.5.6.1.zip: Mapster/Locale/enUS.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local debug = false
--[===[@debug@
debug = true
--@end-debug@]===]

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "enUS", true, debug)

L["Accuracy"] = true
L["Adjust the size of the Player Arrow on the Map for better visibility."] = true
L["Alpha"] = true
L["Battlegrounds"] = true
L["BattleMap"] = true
L["Blobs & Panels"] = true
L["Burning Crusade Instances"] = true
L["Burning Crusade Raids"] = true
L["Cataclysm Instances"] = true
L["Cataclysm Raids"] = true
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = true
L["Classic Instances"] = true
L["Classic Raids"] = true
L["Coordinates"] = true
L["Cursor"] = true
L["Debug"] = true
L["Disable Mouse"] = true
L["Disable the mouse interactivity of the main map, eg. to change zones."] = true
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = true
L["EJ Icon Scale"] = true
L["Enable BattleMap"] = true
L["Enable Coordinates"] = true
L["Enable FogClear"] = true
L["Enable Group Icons"] = true
L["Enable Instance Maps"] = true
L["FogClear"] = true
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = true
L["Group Icons"] = true
L["Hide Border"] = true
L["Hide Completely"] = true
L["Hide Map Button"] = true
L["Hide Quest Panels"] = true
L["Hide Textures"] = true
L["Hide the borders of the big map."] = true
L["Hide the borders of the minimized map."] = true
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = true
L["Instance Maps"] = true
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = true
L["(Mini) Disable Mouse"] = true
L["(Mini) Hide Border"] = true
L["Minimized Alpha"] = true
L["Minimized Scale"] = true
L["Note: You need to reload your UI after reseting the data!"] = true
L["Only WorldMap Blobs"] = true
L["Overlay Color"] = true
L["Pandaria Instances"] = true
L["Pandaria Raids"] = true
L["Player"] = true
L["PlayerArrow Scale"] = true
L["POI Scale"] = true
L["Reset FogClear Data"] = true
L["Scale"] = true
L["Scale of the big map."] = true
L["Scale of the Encounter Journal Icons on the Map."] = true
L["Scale of the minimized map."] = true
L["Scale of the POI Icons on the Map."] = true
L["Size on the Battle Map"] = true
L["Size on the World Map"] = true
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = true
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = true
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = true
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = true
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = true
L["The transparency of the big map."] = true
L["The transparency of the minimized map."] = true
L["Turn on debugging for the FogClear Module."] = true
L["Wrath Instances"] = true
L["Wrath Raids"] = true
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = true
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = true
